MaterialParityFocusOverlayResolver class abstract final

Resolves M3 focus overlay colors and border sides for the parity renderer.

Follows the same overlay colors used by Flutter's built-in M3 buttons (see _FilledButtonDefaultsM3, _OutlinedButtonDefaultsM3, etc.).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

resolveFocusBorderSide({required BuildContext context, required RButtonVariant variant, required RButtonState state}) BorderSide?
Returns the M3 focus border side for the outlined variant.
resolveOverlayColor({required BuildContext context, required RButtonVariant variant, required RButtonState state}) Color?
Returns the M3 focus overlay color for the given variant.