Builds a ButtonStyle delta from RButtonOverrides.
Maps contract-level overrides to Material's ButtonStyle properties:
textStyle→ButtonStyle.textStyleforegroundColor→ButtonStyle.foregroundColorbackgroundColor→ButtonStyle.backgroundColorpadding→ButtonStyle.paddingminSize→ButtonStyle.minimumSizeborderRadius→ButtonStyle.shape(RoundedRectangleBorder)borderColor→ButtonStyle.side(OutlinedButton only)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromOverrides(
RenderOverrides? overrides, {required bool isOutlined}) → ButtonStyle?