HeadlessMaterialApp class
MaterialApp bootstrap for Headless.
What it does:
- Provides
HeadlessThemeProviderwith MaterialHeadlessTheme by default. - Installs
AnchoredOverlayEngineHost(required for overlay-based components). - Manages
OverlayControllerlifecycle unless you pass one.
Intended to reduce onboarding boilerplate:
HeadlessThemeProvider + AnchoredOverlayEngineHost + MaterialApp(...).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- HeadlessMaterialApp
Constructors
-
HeadlessMaterialApp({Key? key, HeadlessTheme? headlessTheme, OverlayController? overlayController, bool enableAutoRepositionTicker = false, bool requireResolvedTokens = true, String title = '', bool debugShowCheckedModeBanner = false, ThemeData? theme, ThemeData? darkTheme, ThemeMode? themeMode, Color? color, Widget? home, Map<
String, WidgetBuilder> routes = const <String, WidgetBuilder>{}, String? initialRoute, RouteFactory? onGenerateRoute, RouteFactory? onUnknownRoute, GlobalKey<ScaffoldMessengerState> ? scaffoldMessengerKey, TransitionBuilder? builder, Locale? locale, Iterable<LocalizationsDelegate> ? localizationsDelegates, LocaleResolutionCallback? localeResolutionCallback, Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')]}) -
const
Properties
- builder → TransitionBuilder?
-
final
- color → Color?
-
final
- darkTheme → ThemeData?
-
final
- debugShowCheckedModeBanner → bool
-
final
- enableAutoRepositionTicker → bool
-
When enabled, AnchoredOverlayEngineHost will request reposition every frame while overlays
are active.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headlessTheme → HeadlessTheme?
-
Headless theme used by components (capability provider).
final
- home → Widget?
-
final
- initialRoute → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- locale → Locale?
-
final
- localeResolutionCallback → LocaleResolutionCallback?
-
final
-
localizationsDelegates
→ Iterable<
LocalizationsDelegate> ? -
final
-
final
- onGenerateRoute → RouteFactory?
-
final
- onUnknownRoute → RouteFactory?
-
final
- overlayController → OverlayController?
-
Optional external overlay controller.
final
- requireResolvedTokens → bool
-
When true, preset renderers require non-null resolvedTokens.
final
-
routes
→ Map<
String, WidgetBuilder> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaffoldMessengerKey
→ GlobalKey<
ScaffoldMessengerState> ? -
final
-
supportedLocales
→ Iterable<
Locale> -
final
- theme → ThemeData?
-
final
- themeMode → ThemeMode?
-
final
- title → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< HeadlessMaterialApp> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited