MaterialInkPressableSurface class

Material implementation of HeadlessPressableSurfaceFactory.

Uses Material + InkResponse for ripple effects. Reads splash factory and colors from Theme and ListTileTheme.

Constructors

MaterialInkPressableSurface()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap({required BuildContext context, required HeadlessPressableController controller, required bool enabled, required VoidCallback onActivate, required Widget child, RenderOverrides? overrides, HeadlessPressableVisualEffectsController? visualEffects, FocusNode? focusNode, bool autofocus = false, MouseCursor? cursorWhenEnabled, MouseCursor? cursorWhenDisabled}) Widget
Wraps the child widget with an interactive pressable surface.

Operators

operator ==(Object other) bool
The equality operator.
inherited