MaterialSwitchRenderer class
Material 3 renderer for Switch components.
Invariants:
- Renderer never calls user callbacks directly.
- Interaction/gestures live in the component (HeadlessPressableRegion).
Supports drag interpolation via RSwitchState.dragT.
Constructors
- MaterialSwitchRenderer()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
RSwitchRenderRequest request) → Widget - Render a switch with the given request.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited